JasonWoof Got questions, comments, patches, etc.? Contact Jason Woofenden
renamed seltag into seltags
[dwm.git] / dwm.h
diff --git a/dwm.h b/dwm.h
index 509b845..f527a3f 100644 (file)
--- a/dwm.h
+++ b/dwm.h
@@ -82,7 +82,7 @@ extern unsigned int bh, blw, bpos;            /* bar height, bar layout label width, bar p
 extern unsigned int ntags, numlockmask;                /* number of tags, numlock mask */
 extern void (*handler[LASTEvent])(XEvent *);   /* event handler */
 extern Atom dwmconfig, wmatom[WMLast], netatom[NetLast];
-extern Bool selscreen, *seltag;                        /* seltag is array of Bool */
+extern Bool selscreen, *seltags;               /* seltags is array of Bool */
 extern Client *clients, *sel, *stack;          /* global client list and stack */
 extern Cursor cursor[CurLast];
 extern DC dc;                                  /* global draw context */
@@ -114,7 +114,8 @@ void grabkeys(void);                        /* grab all keys defined in config.h */
 
 /* layout.c */
 void arrange(void);                    /* arranges all windows depending on the layout in use */
-void focusclient(const char *arg);     /* focuses next(1)/previous(-1) visible client */
+void focusnext(const char *arg);       /* focuses next visible client */
+void focusprev(const char *arg);       /* focuses prev visible client */
 const char *getsymbol(void);           /* returns symbol of enabled layout */
 Bool isfloating(void);                 /* returns True if floating layout is enabled */
 Bool isarrange(void (*func)());                /* returns True if func is the layout function in use */